@@ -185,6 +185,9 @@ pub const LIBSSH2_CHANNEL_EXTENDED_DATA_NORMAL: c_int = 0;
 pub const LIBSSH2_CHANNEL_EXTENDED_DATA_IGNORE: c_int = 1;
 pub const LIBSSH2_CHANNEL_EXTENDED_DATA_MERGE: c_int = 2;
 
+pub const LIBSSH2_SESSION_BLOCK_INBOUND: c_int = 1;
+pub const LIBSSH2_SESSION_BLOCK_OUTBOUND: c_int = 2;
+
 pub enum LIBSSH2_SESSION {}
 pub enum LIBSSH2_AGENT {}
 pub enum LIBSSH2_CHANNEL {}
@@ -296,9 +299,9 @@ pub struct LIBSSH2_USERAUTH_KBDINT_RESPONSE {
 
 #[cfg(unix)]
 pub type libssh2_socket_t = c_int;
-#[cfg(all(windows, target_arch = "x86"))]
+#[cfg(all(windows, target_pointer_width = "32"))]
 pub type libssh2_socket_t = u32;
-#[cfg(all(windows, target_arch = "x86_64"))]
+#[cfg(all(windows, target_pointer_width = "64"))]
 pub type libssh2_socket_t = u64;
 
 extern "C" {
@@ -347,6 +350,7 @@ extern "C" {
         method_type: c_int,
         algs: *mut *mut *const c_char,
     ) -> c_int;
+    pub fn libssh2_session_last_errno(sess: *mut LIBSSH2_SESSION) -> c_int;
     pub fn libssh2_session_last_error(
         sess: *mut LIBSSH2_SESSION,
         msg: *mut *mut c_char,
@@ -362,6 +366,7 @@ extern "C" {
     );
     pub fn libssh2_keepalive_send(sess: *mut LIBSSH2_SESSION, seconds_to_next: *mut c_int)
         -> c_int;
+    pub fn libssh2_session_block_directions(sess: *mut LIBSSH2_SESSION) -> c_int;
 
     // agent
     pub fn libssh2_agent_init(sess: *mut LIBSSH2_SESSION) -> *mut LIBSSH2_AGENT;
@@ -486,6 +491,7 @@ extern "C" {
         channel: *mut LIBSSH2_CHANNEL,
         mode: c_int,
     ) -> c_int;
+    pub fn libssh2_channel_request_auth_agent(channel: *mut LIBSSH2_CHANNEL) -> c_int;
 
     // userauth
     pub fn libssh2_userauth_authenticated(sess: *mut LIBSSH2_SESSION) -> c_int;
